##  Introduction
The SBOM explorer helps you understand and manage the open-source libraries used in your organization. It also helps you effectively manage dependencies, reduce risks, ensure compliance, and improve software development and IT operations.
With the software bill of materials view, you can:
  * Understand open-source usage: Understand how open-source libraries are used across your organization's IT infrastructure, including which microservices depend on them, which applications they support, etc.
  * Track affected parts during cybersecurity incidents: Quickly identify which parts of your IT system are impacted during cybersecurity incidents, like the log4shell vulnerability.
  * Formulate immediate risk mitigation initiatives: Take swift action to address vulnerabilities, for example, by prioritizing updates or patches to affected components.


![Software Bill of Materials View](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274593e37a441014ba35951cd31b185e_LowRes.png)
SBOM Explorer
